.. _contrib:

=============
click-contrib
=============

As the number of users of Click grows, more and more major feature requests are
made. To users it may seem reasonable to include those features with Click;
however, many of them are experimental or aren't practical to support
generically. Maintainers have to choose what is reasonable to maintain in Click
core.

The click-contrib_ GitHub organization exists as a place to collect third-party
packages that extend Click's features. It is also meant to ease the effort of
searching for such extensions.

Please note that the quality and stability of those packages may be different
than Click itself. While published under a common organization, they are still
separate from Click and the Pallets maintainers.

.. _click-contrib: https://github.com/click-contrib/
